==> gworkspace_0.7.0.orig.tar.gz: gworkspace-0.7.0.orig/GWorkspace/Dialogs/RunExternalController.h <==
/* RunExternalController.h
 *  
 * Copyright (C) 2003 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: August 2001
 *
 * This file is part of the GNUstep GWorkspace application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef RUN_EXTERNAL_CONTROLLER_H
#define RUN_EXTERNAL_CONTROLLER_H

#include <Foundation/NSObject.h>

@class CompletionField;
@class NSFileManager;
@class NSArray;

@interface RunExternalController : NSObject 
{
  IBOutlet id win;
  IBOutlet id titleLabel;
  IBOutlet id secondLabel;
  IBOutlet id fieldBox;
  IBOutlet id cancelButt;
  IBOutlet id okButt;
  
  CompletionField *cfield;
  unsigned result;  
  
  NSArray *pathsArr;
  NSFileManager *fm;
  
}

- (NSString *)checkCommand:(NSString *)comm;

- (void)activate;

- (IBAction)cancelButtAction:(id)sender;

- (IBAction)okButtAction:(id)sender;

@end

#endif // RUN_EXTERNAL_CONTROLLER_H

==> gworkspace_0.8.8.orig.tar.gz: gworkspace-0.8.8/GWorkspace/Dialogs/RunExternalController.h <==
/* RunExternalController.h
 *  
 * Copyright (C) 2003 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: August 2001
 *
 * This file is part of the GNUstep GWorkspace application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */


#ifndef RUN_EXTERNAL_CONTROLLER_H
#define RUN_EXTERNAL_CONTROLLER_H

#include <Foundation/Foundation.h>

@class CompletionField;
@class NSBox;
@class NSWindow;

@interface RunExternalController : NSObject 
{
  IBOutlet id win;
  IBOutlet id titleLabel;
  IBOutlet id secondLabel;
  IBOutlet id cancelButt;
  IBOutlet id okButt;
  
  IBOutlet CompletionField *cfield;
  unsigned result;  
  
  NSArray *pathsArr;
  NSFileManager *fm;
  
}

- (NSString *)checkCommand:(NSString *)comm;

- (void)activate;

- (NSWindow *)win;

- (IBAction)cancelButtAction:(id)sender;

- (IBAction)okButtAction:(id)sender;

- (void)completionFieldDidEndLine:(id)afield;

@end

#endif // RUN_EXTERNAL_CONTROLLER_H
